"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3547 import (
        AbstractAssemblySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3548 import (
        AbstractShaftOrHousingSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3549 import (
        AbstractShaftSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3550 import (
        AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3551 import (
        AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3552 import (
        AGMAGleasonConicalGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3553 import (
        AGMAGleasonConicalGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3554 import (
        AssemblySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3555 import (
        BearingSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3556 import (
        BeltConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3557 import (
        BeltDriveSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3558 import (
        BevelDifferentialGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3559 import (
        BevelDifferentialGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3560 import (
        BevelDifferentialGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3561 import (
        BevelDifferentialPlanetGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3562 import (
        BevelDifferentialSunGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3563 import (
        BevelGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3564 import (
        BevelGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3565 import (
        BevelGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3566 import (
        BoltedJointSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3567 import (
        BoltSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3568 import (
        ClutchConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3569 import (
        ClutchHalfSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3570 import (
        ClutchSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3571 import (
        CoaxialConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3572 import (
        ComponentSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3573 import (
        ConceptCouplingConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3574 import (
        ConceptCouplingHalfSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3575 import (
        ConceptCouplingSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3576 import (
        ConceptGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3577 import (
        ConceptGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3578 import (
        ConceptGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3579 import (
        ConicalGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3580 import (
        ConicalGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3581 import (
        ConicalGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3582 import (
        ConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3583 import (
        ConnectorSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3584 import (
        CouplingConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3585 import (
        CouplingHalfSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3586 import (
        CouplingSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3587 import (
        CVTBeltConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3588 import (
        CVTPulleySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3589 import (
        CVTSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3590 import (
        CycloidalAssemblySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3591 import (
        CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3592 import (
        CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3593 import (
        CycloidalDiscSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3594 import (
        CylindricalGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3595 import (
        CylindricalGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3596 import (
        CylindricalGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3597 import (
        CylindricalPlanetGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3598 import (
        DatumSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3599 import (
        ExternalCADModelSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3600 import (
        FaceGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3601 import (
        FaceGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3602 import (
        FaceGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3603 import (
        FEPartSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3604 import (
        FlexiblePinAssemblySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3605 import (
        GearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3606 import (
        GearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3607 import (
        GearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3608 import (
        GuideDxfModelSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3609 import (
        HypoidGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3610 import (
        HypoidGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3611 import (
        HypoidGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3612 import (
        InterMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3613 import (
        KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3614 import (
        KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3615 import (
        KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3616 import (
        KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3617 import (
        KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3618 import (
        KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3619 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3620 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3621 import (
        KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3622 import (
        MassDiscSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3623 import (
        MeasurementComponentSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3624 import (
        MicrophoneArraySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3625 import (
        MicrophoneSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3626 import (
        MountableComponentSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3627 import (
        OilSealSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3628 import (
        PartSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3629 import (
        PartToPartShearCouplingConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3630 import (
        PartToPartShearCouplingHalfSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3631 import (
        PartToPartShearCouplingSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3632 import (
        PlanetaryConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3633 import (
        PlanetaryGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3634 import (
        PlanetCarrierSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3635 import (
        PointLoadSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3636 import (
        PowerLoadSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3637 import (
        PulleySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3638 import (
        RingPinsSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3639 import (
        RingPinsToDiscConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3640 import (
        RollingRingAssemblySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3641 import (
        RollingRingConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3642 import (
        RollingRingSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3643 import (
        RootAssemblySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3644 import (
        ShaftHubConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3645 import (
        ShaftSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3646 import (
        ShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3647 import (
        SpecialisedAssemblySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3648 import (
        SpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3649 import (
        SpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3650 import (
        SpiralBevelGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3651 import (
        SpringDamperConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3652 import (
        SpringDamperHalfSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3653 import (
        SpringDamperSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3654 import (
        SteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3655 import (
        StraightBevelDiffGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3656 import (
        StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3657 import (
        StraightBevelDiffGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3658 import (
        StraightBevelGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3659 import (
        StraightBevelGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3660 import (
        StraightBevelGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3661 import (
        StraightBevelPlanetGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3662 import (
        StraightBevelSunGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3663 import (
        SynchroniserHalfSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3664 import (
        SynchroniserPartSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3665 import (
        SynchroniserSleeveSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3666 import (
        SynchroniserSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3667 import (
        TorqueConverterConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3668 import (
        TorqueConverterPumpSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3669 import (
        TorqueConverterSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3670 import (
        TorqueConverterTurbineSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3671 import (
        UnbalancedMassSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3672 import (
        VirtualComponentSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3673 import (
        WormGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3674 import (
        WormGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3675 import (
        WormGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3676 import (
        ZerolBevelGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3677 import (
        ZerolBevelGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3678 import (
        ZerolBevelGearSteadyStateSynchronousResponseOnAShaft,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3547": [
            "AbstractAssemblySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3548": [
            "AbstractShaftOrHousingSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3549": [
            "AbstractShaftSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3550": [
            "AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3551": [
            "AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3552": [
            "AGMAGleasonConicalGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3553": [
            "AGMAGleasonConicalGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3554": [
            "AssemblySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3555": [
            "BearingSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3556": [
            "BeltConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3557": [
            "BeltDriveSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3558": [
            "BevelDifferentialGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3559": [
            "BevelDifferentialGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3560": [
            "BevelDifferentialGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3561": [
            "BevelDifferentialPlanetGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3562": [
            "BevelDifferentialSunGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3563": [
            "BevelGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3564": [
            "BevelGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3565": [
            "BevelGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3566": [
            "BoltedJointSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3567": [
            "BoltSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3568": [
            "ClutchConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3569": [
            "ClutchHalfSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3570": [
            "ClutchSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3571": [
            "CoaxialConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3572": [
            "ComponentSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3573": [
            "ConceptCouplingConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3574": [
            "ConceptCouplingHalfSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3575": [
            "ConceptCouplingSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3576": [
            "ConceptGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3577": [
            "ConceptGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3578": [
            "ConceptGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3579": [
            "ConicalGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3580": [
            "ConicalGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3581": [
            "ConicalGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3582": [
            "ConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3583": [
            "ConnectorSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3584": [
            "CouplingConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3585": [
            "CouplingHalfSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3586": [
            "CouplingSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3587": [
            "CVTBeltConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3588": [
            "CVTPulleySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3589": [
            "CVTSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3590": [
            "CycloidalAssemblySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3591": [
            "CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3592": [
            "CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3593": [
            "CycloidalDiscSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3594": [
            "CylindricalGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3595": [
            "CylindricalGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3596": [
            "CylindricalGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3597": [
            "CylindricalPlanetGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3598": [
            "DatumSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3599": [
            "ExternalCADModelSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3600": [
            "FaceGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3601": [
            "FaceGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3602": [
            "FaceGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3603": [
            "FEPartSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3604": [
            "FlexiblePinAssemblySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3605": [
            "GearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3606": [
            "GearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3607": [
            "GearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3608": [
            "GuideDxfModelSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3609": [
            "HypoidGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3610": [
            "HypoidGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3611": [
            "HypoidGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3612": [
            "InterMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3613": [
            "KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3614": [
            "KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3615": [
            "KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3616": [
            "KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3617": [
            "KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3618": [
            "KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3619": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3620": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3621": [
            "KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3622": [
            "MassDiscSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3623": [
            "MeasurementComponentSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3624": [
            "MicrophoneArraySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3625": [
            "MicrophoneSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3626": [
            "MountableComponentSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3627": [
            "OilSealSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3628": [
            "PartSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3629": [
            "PartToPartShearCouplingConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3630": [
            "PartToPartShearCouplingHalfSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3631": [
            "PartToPartShearCouplingSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3632": [
            "PlanetaryConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3633": [
            "PlanetaryGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3634": [
            "PlanetCarrierSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3635": [
            "PointLoadSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3636": [
            "PowerLoadSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3637": [
            "PulleySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3638": [
            "RingPinsSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3639": [
            "RingPinsToDiscConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3640": [
            "RollingRingAssemblySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3641": [
            "RollingRingConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3642": [
            "RollingRingSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3643": [
            "RootAssemblySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3644": [
            "ShaftHubConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3645": [
            "ShaftSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3646": [
            "ShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3647": [
            "SpecialisedAssemblySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3648": [
            "SpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3649": [
            "SpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3650": [
            "SpiralBevelGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3651": [
            "SpringDamperConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3652": [
            "SpringDamperHalfSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3653": [
            "SpringDamperSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3654": [
            "SteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3655": [
            "StraightBevelDiffGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3656": [
            "StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3657": [
            "StraightBevelDiffGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3658": [
            "StraightBevelGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3659": [
            "StraightBevelGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3660": [
            "StraightBevelGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3661": [
            "StraightBevelPlanetGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3662": [
            "StraightBevelSunGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3663": [
            "SynchroniserHalfSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3664": [
            "SynchroniserPartSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3665": [
            "SynchroniserSleeveSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3666": [
            "SynchroniserSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3667": [
            "TorqueConverterConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3668": [
            "TorqueConverterPumpSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3669": [
            "TorqueConverterSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3670": [
            "TorqueConverterTurbineSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3671": [
            "UnbalancedMassSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3672": [
            "VirtualComponentSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3673": [
            "WormGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3674": [
            "WormGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3675": [
            "WormGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3676": [
            "ZerolBevelGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3677": [
            "ZerolBevelGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3678": [
            "ZerolBevelGearSteadyStateSynchronousResponseOnAShaft"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblySteadyStateSynchronousResponseOnAShaft",
    "AbstractShaftOrHousingSteadyStateSynchronousResponseOnAShaft",
    "AbstractShaftSteadyStateSynchronousResponseOnAShaft",
    "AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft",
    "AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseOnAShaft",
    "AGMAGleasonConicalGearSetSteadyStateSynchronousResponseOnAShaft",
    "AGMAGleasonConicalGearSteadyStateSynchronousResponseOnAShaft",
    "AssemblySteadyStateSynchronousResponseOnAShaft",
    "BearingSteadyStateSynchronousResponseOnAShaft",
    "BeltConnectionSteadyStateSynchronousResponseOnAShaft",
    "BeltDriveSteadyStateSynchronousResponseOnAShaft",
    "BevelDifferentialGearMeshSteadyStateSynchronousResponseOnAShaft",
    "BevelDifferentialGearSetSteadyStateSynchronousResponseOnAShaft",
    "BevelDifferentialGearSteadyStateSynchronousResponseOnAShaft",
    "BevelDifferentialPlanetGearSteadyStateSynchronousResponseOnAShaft",
    "BevelDifferentialSunGearSteadyStateSynchronousResponseOnAShaft",
    "BevelGearMeshSteadyStateSynchronousResponseOnAShaft",
    "BevelGearSetSteadyStateSynchronousResponseOnAShaft",
    "BevelGearSteadyStateSynchronousResponseOnAShaft",
    "BoltedJointSteadyStateSynchronousResponseOnAShaft",
    "BoltSteadyStateSynchronousResponseOnAShaft",
    "ClutchConnectionSteadyStateSynchronousResponseOnAShaft",
    "ClutchHalfSteadyStateSynchronousResponseOnAShaft",
    "ClutchSteadyStateSynchronousResponseOnAShaft",
    "CoaxialConnectionSteadyStateSynchronousResponseOnAShaft",
    "ComponentSteadyStateSynchronousResponseOnAShaft",
    "ConceptCouplingConnectionSteadyStateSynchronousResponseOnAShaft",
    "ConceptCouplingHalfSteadyStateSynchronousResponseOnAShaft",
    "ConceptCouplingSteadyStateSynchronousResponseOnAShaft",
    "ConceptGearMeshSteadyStateSynchronousResponseOnAShaft",
    "ConceptGearSetSteadyStateSynchronousResponseOnAShaft",
    "ConceptGearSteadyStateSynchronousResponseOnAShaft",
    "ConicalGearMeshSteadyStateSynchronousResponseOnAShaft",
    "ConicalGearSetSteadyStateSynchronousResponseOnAShaft",
    "ConicalGearSteadyStateSynchronousResponseOnAShaft",
    "ConnectionSteadyStateSynchronousResponseOnAShaft",
    "ConnectorSteadyStateSynchronousResponseOnAShaft",
    "CouplingConnectionSteadyStateSynchronousResponseOnAShaft",
    "CouplingHalfSteadyStateSynchronousResponseOnAShaft",
    "CouplingSteadyStateSynchronousResponseOnAShaft",
    "CVTBeltConnectionSteadyStateSynchronousResponseOnAShaft",
    "CVTPulleySteadyStateSynchronousResponseOnAShaft",
    "CVTSteadyStateSynchronousResponseOnAShaft",
    "CycloidalAssemblySteadyStateSynchronousResponseOnAShaft",
    "CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseOnAShaft",
    "CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseOnAShaft",
    "CycloidalDiscSteadyStateSynchronousResponseOnAShaft",
    "CylindricalGearMeshSteadyStateSynchronousResponseOnAShaft",
    "CylindricalGearSetSteadyStateSynchronousResponseOnAShaft",
    "CylindricalGearSteadyStateSynchronousResponseOnAShaft",
    "CylindricalPlanetGearSteadyStateSynchronousResponseOnAShaft",
    "DatumSteadyStateSynchronousResponseOnAShaft",
    "ExternalCADModelSteadyStateSynchronousResponseOnAShaft",
    "FaceGearMeshSteadyStateSynchronousResponseOnAShaft",
    "FaceGearSetSteadyStateSynchronousResponseOnAShaft",
    "FaceGearSteadyStateSynchronousResponseOnAShaft",
    "FEPartSteadyStateSynchronousResponseOnAShaft",
    "FlexiblePinAssemblySteadyStateSynchronousResponseOnAShaft",
    "GearMeshSteadyStateSynchronousResponseOnAShaft",
    "GearSetSteadyStateSynchronousResponseOnAShaft",
    "GearSteadyStateSynchronousResponseOnAShaft",
    "GuideDxfModelSteadyStateSynchronousResponseOnAShaft",
    "HypoidGearMeshSteadyStateSynchronousResponseOnAShaft",
    "HypoidGearSetSteadyStateSynchronousResponseOnAShaft",
    "HypoidGearSteadyStateSynchronousResponseOnAShaft",
    "InterMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseOnAShaft",
    "MassDiscSteadyStateSynchronousResponseOnAShaft",
    "MeasurementComponentSteadyStateSynchronousResponseOnAShaft",
    "MicrophoneArraySteadyStateSynchronousResponseOnAShaft",
    "MicrophoneSteadyStateSynchronousResponseOnAShaft",
    "MountableComponentSteadyStateSynchronousResponseOnAShaft",
    "OilSealSteadyStateSynchronousResponseOnAShaft",
    "PartSteadyStateSynchronousResponseOnAShaft",
    "PartToPartShearCouplingConnectionSteadyStateSynchronousResponseOnAShaft",
    "PartToPartShearCouplingHalfSteadyStateSynchronousResponseOnAShaft",
    "PartToPartShearCouplingSteadyStateSynchronousResponseOnAShaft",
    "PlanetaryConnectionSteadyStateSynchronousResponseOnAShaft",
    "PlanetaryGearSetSteadyStateSynchronousResponseOnAShaft",
    "PlanetCarrierSteadyStateSynchronousResponseOnAShaft",
    "PointLoadSteadyStateSynchronousResponseOnAShaft",
    "PowerLoadSteadyStateSynchronousResponseOnAShaft",
    "PulleySteadyStateSynchronousResponseOnAShaft",
    "RingPinsSteadyStateSynchronousResponseOnAShaft",
    "RingPinsToDiscConnectionSteadyStateSynchronousResponseOnAShaft",
    "RollingRingAssemblySteadyStateSynchronousResponseOnAShaft",
    "RollingRingConnectionSteadyStateSynchronousResponseOnAShaft",
    "RollingRingSteadyStateSynchronousResponseOnAShaft",
    "RootAssemblySteadyStateSynchronousResponseOnAShaft",
    "ShaftHubConnectionSteadyStateSynchronousResponseOnAShaft",
    "ShaftSteadyStateSynchronousResponseOnAShaft",
    "ShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft",
    "SpecialisedAssemblySteadyStateSynchronousResponseOnAShaft",
    "SpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft",
    "SpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft",
    "SpiralBevelGearSteadyStateSynchronousResponseOnAShaft",
    "SpringDamperConnectionSteadyStateSynchronousResponseOnAShaft",
    "SpringDamperHalfSteadyStateSynchronousResponseOnAShaft",
    "SpringDamperSteadyStateSynchronousResponseOnAShaft",
    "SteadyStateSynchronousResponseOnAShaft",
    "StraightBevelDiffGearMeshSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelDiffGearSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelGearMeshSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelGearSetSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelGearSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelPlanetGearSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelSunGearSteadyStateSynchronousResponseOnAShaft",
    "SynchroniserHalfSteadyStateSynchronousResponseOnAShaft",
    "SynchroniserPartSteadyStateSynchronousResponseOnAShaft",
    "SynchroniserSleeveSteadyStateSynchronousResponseOnAShaft",
    "SynchroniserSteadyStateSynchronousResponseOnAShaft",
    "TorqueConverterConnectionSteadyStateSynchronousResponseOnAShaft",
    "TorqueConverterPumpSteadyStateSynchronousResponseOnAShaft",
    "TorqueConverterSteadyStateSynchronousResponseOnAShaft",
    "TorqueConverterTurbineSteadyStateSynchronousResponseOnAShaft",
    "UnbalancedMassSteadyStateSynchronousResponseOnAShaft",
    "VirtualComponentSteadyStateSynchronousResponseOnAShaft",
    "WormGearMeshSteadyStateSynchronousResponseOnAShaft",
    "WormGearSetSteadyStateSynchronousResponseOnAShaft",
    "WormGearSteadyStateSynchronousResponseOnAShaft",
    "ZerolBevelGearMeshSteadyStateSynchronousResponseOnAShaft",
    "ZerolBevelGearSetSteadyStateSynchronousResponseOnAShaft",
    "ZerolBevelGearSteadyStateSynchronousResponseOnAShaft",
)



"""MountableComponentSteadyStateSynchronousResponseOnAShaft"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
    _3572,
)

_MOUNTABLE_COMPONENT_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesOnAShaft",
    "MountableComponentSteadyStateSynchronousResponseOnAShaft",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944, _2946, _2950
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7943,
        _7946,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
        _3553,
        _3555,
        _3560,
        _3561,
        _3562,
        _3565,
        _3569,
        _3574,
        _3578,
        _3581,
        _3583,
        _3585,
        _3588,
        _3596,
        _3597,
        _3602,
        _3607,
        _3611,
        _3615,
        _3618,
        _3621,
        _3622,
        _3623,
        _3627,
        _3628,
        _3630,
        _3634,
        _3635,
        _3636,
        _3637,
        _3638,
        _3642,
        _3644,
        _3650,
        _3652,
        _3657,
        _3660,
        _3661,
        _3662,
        _3663,
        _3664,
        _3665,
        _3668,
        _3670,
        _3671,
        _3672,
        _3675,
        _3678,
    )
    from mastapy._private.system_model.part_model import _2738

    Self = TypeVar(
        "Self", bound="MountableComponentSteadyStateSynchronousResponseOnAShaft"
    )
    CastSelf = TypeVar(
        "CastSelf",
        bound="MountableComponentSteadyStateSynchronousResponseOnAShaft._Cast_MountableComponentSteadyStateSynchronousResponseOnAShaft",
    )


__docformat__ = "restructuredtext en"
__all__ = ("MountableComponentSteadyStateSynchronousResponseOnAShaft",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_MountableComponentSteadyStateSynchronousResponseOnAShaft:
    """Special nested class for casting MountableComponentSteadyStateSynchronousResponseOnAShaft to subclasses."""

    __parent__: "MountableComponentSteadyStateSynchronousResponseOnAShaft"

    @property
    def component_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3572.ComponentSteadyStateSynchronousResponseOnAShaft":
        return self.__parent__._cast(
            _3572.ComponentSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def part_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3628.PartSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3628,
        )

        return self.__parent__._cast(_3628.PartSteadyStateSynchronousResponseOnAShaft)

    @property
    def part_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7946.PartStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7946,
        )

        return self.__parent__._cast(_7946.PartStaticLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7943.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7943,
        )

        return self.__parent__._cast(_7943.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2950.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2950

        return self.__parent__._cast(_2950.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3553.AGMAGleasonConicalGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3553,
        )

        return self.__parent__._cast(
            _3553.AGMAGleasonConicalGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def bearing_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3555.BearingSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3555,
        )

        return self.__parent__._cast(
            _3555.BearingSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def bevel_differential_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3560.BevelDifferentialGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3560,
        )

        return self.__parent__._cast(
            _3560.BevelDifferentialGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def bevel_differential_planet_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3561.BevelDifferentialPlanetGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3561,
        )

        return self.__parent__._cast(
            _3561.BevelDifferentialPlanetGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def bevel_differential_sun_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3562.BevelDifferentialSunGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3562,
        )

        return self.__parent__._cast(
            _3562.BevelDifferentialSunGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def bevel_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3565.BevelGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3565,
        )

        return self.__parent__._cast(
            _3565.BevelGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def clutch_half_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3569.ClutchHalfSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3569,
        )

        return self.__parent__._cast(
            _3569.ClutchHalfSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def concept_coupling_half_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3574.ConceptCouplingHalfSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3574,
        )

        return self.__parent__._cast(
            _3574.ConceptCouplingHalfSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def concept_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3578.ConceptGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3578,
        )

        return self.__parent__._cast(
            _3578.ConceptGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def conical_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3581.ConicalGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3581,
        )

        return self.__parent__._cast(
            _3581.ConicalGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def connector_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3583.ConnectorSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3583,
        )

        return self.__parent__._cast(
            _3583.ConnectorSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def coupling_half_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3585.CouplingHalfSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3585,
        )

        return self.__parent__._cast(
            _3585.CouplingHalfSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def cvt_pulley_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3588.CVTPulleySteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3588,
        )

        return self.__parent__._cast(
            _3588.CVTPulleySteadyStateSynchronousResponseOnAShaft
        )

    @property
    def cylindrical_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3596.CylindricalGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3596,
        )

        return self.__parent__._cast(
            _3596.CylindricalGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def cylindrical_planet_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3597.CylindricalPlanetGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3597,
        )

        return self.__parent__._cast(
            _3597.CylindricalPlanetGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def face_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3602.FaceGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3602,
        )

        return self.__parent__._cast(
            _3602.FaceGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3607.GearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3607,
        )

        return self.__parent__._cast(_3607.GearSteadyStateSynchronousResponseOnAShaft)

    @property
    def hypoid_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3611.HypoidGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3611,
        )

        return self.__parent__._cast(
            _3611.HypoidGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def klingelnberg_cyclo_palloid_conical_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3615.KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3615,
        )

        return self.__parent__._cast(
            _3615.KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> (
        "_3618.KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseOnAShaft"
    ):
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3618,
        )

        return self.__parent__._cast(
            _3618.KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3621.KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3621,
        )

        return self.__parent__._cast(
            _3621.KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def mass_disc_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3622.MassDiscSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3622,
        )

        return self.__parent__._cast(
            _3622.MassDiscSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def measurement_component_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3623.MeasurementComponentSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3623,
        )

        return self.__parent__._cast(
            _3623.MeasurementComponentSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def oil_seal_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3627.OilSealSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3627,
        )

        return self.__parent__._cast(
            _3627.OilSealSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def part_to_part_shear_coupling_half_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3630.PartToPartShearCouplingHalfSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3630,
        )

        return self.__parent__._cast(
            _3630.PartToPartShearCouplingHalfSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def planet_carrier_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3634.PlanetCarrierSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3634,
        )

        return self.__parent__._cast(
            _3634.PlanetCarrierSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def point_load_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3635.PointLoadSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3635,
        )

        return self.__parent__._cast(
            _3635.PointLoadSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def power_load_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3636.PowerLoadSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3636,
        )

        return self.__parent__._cast(
            _3636.PowerLoadSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def pulley_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3637.PulleySteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3637,
        )

        return self.__parent__._cast(_3637.PulleySteadyStateSynchronousResponseOnAShaft)

    @property
    def ring_pins_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3638.RingPinsSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3638,
        )

        return self.__parent__._cast(
            _3638.RingPinsSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def rolling_ring_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3642.RollingRingSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3642,
        )

        return self.__parent__._cast(
            _3642.RollingRingSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def shaft_hub_connection_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3644.ShaftHubConnectionSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3644,
        )

        return self.__parent__._cast(
            _3644.ShaftHubConnectionSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def spiral_bevel_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3650.SpiralBevelGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3650,
        )

        return self.__parent__._cast(
            _3650.SpiralBevelGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def spring_damper_half_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3652.SpringDamperHalfSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3652,
        )

        return self.__parent__._cast(
            _3652.SpringDamperHalfSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def straight_bevel_diff_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3657.StraightBevelDiffGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3657,
        )

        return self.__parent__._cast(
            _3657.StraightBevelDiffGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def straight_bevel_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3660.StraightBevelGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3660,
        )

        return self.__parent__._cast(
            _3660.StraightBevelGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def straight_bevel_planet_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3661.StraightBevelPlanetGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3661,
        )

        return self.__parent__._cast(
            _3661.StraightBevelPlanetGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def straight_bevel_sun_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3662.StraightBevelSunGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3662,
        )

        return self.__parent__._cast(
            _3662.StraightBevelSunGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def synchroniser_half_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3663.SynchroniserHalfSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3663,
        )

        return self.__parent__._cast(
            _3663.SynchroniserHalfSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def synchroniser_part_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3664.SynchroniserPartSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3664,
        )

        return self.__parent__._cast(
            _3664.SynchroniserPartSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def synchroniser_sleeve_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3665.SynchroniserSleeveSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3665,
        )

        return self.__parent__._cast(
            _3665.SynchroniserSleeveSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def torque_converter_pump_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3668.TorqueConverterPumpSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3668,
        )

        return self.__parent__._cast(
            _3668.TorqueConverterPumpSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def torque_converter_turbine_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3670.TorqueConverterTurbineSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3670,
        )

        return self.__parent__._cast(
            _3670.TorqueConverterTurbineSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def unbalanced_mass_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3671.UnbalancedMassSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3671,
        )

        return self.__parent__._cast(
            _3671.UnbalancedMassSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def virtual_component_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3672.VirtualComponentSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3672,
        )

        return self.__parent__._cast(
            _3672.VirtualComponentSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def worm_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3675.WormGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3675,
        )

        return self.__parent__._cast(
            _3675.WormGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def zerol_bevel_gear_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3678.ZerolBevelGearSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3678,
        )

        return self.__parent__._cast(
            _3678.ZerolBevelGearSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def mountable_component_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "MountableComponentSteadyStateSynchronousResponseOnAShaft":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class MountableComponentSteadyStateSynchronousResponseOnAShaft(
    _3572.ComponentSteadyStateSynchronousResponseOnAShaft
):
    """MountableComponentSteadyStateSynchronousResponseOnAShaft

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = (
        _MOUNTABLE_COMPONENT_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT
    )

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_design(self: "Self") -> "_2738.MountableComponent":
        """mastapy.system_model.part_model.MountableComponent

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_MountableComponentSteadyStateSynchronousResponseOnAShaft":
        """Cast to another type.

        Returns:
            _Cast_MountableComponentSteadyStateSynchronousResponseOnAShaft
        """
        return _Cast_MountableComponentSteadyStateSynchronousResponseOnAShaft(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.gears.gear_two_d_fe_analysis._1019 import (
        CylindricalGearMeshTIFFAnalysis,
    )
    from mastapy._private.gears.gear_two_d_fe_analysis._1020 import (
        CylindricalGearMeshTIFFAnalysisDutyCycle,
    )
    from mastapy._private.gears.gear_two_d_fe_analysis._1021 import (
        CylindricalGearSetTIFFAnalysis,
    )
    from mastapy._private.gears.gear_two_d_fe_analysis._1022 import (
        CylindricalGearSetTIFFAnalysisDutyCycle,
    )
    from mastapy._private.gears.gear_two_d_fe_analysis._1023 import (
        CylindricalGearTIFFAnalysis,
    )
    from mastapy._private.gears.gear_two_d_fe_analysis._1024 import (
        CylindricalGearTIFFAnalysisDutyCycle,
    )
    from mastapy._private.gears.gear_two_d_fe_analysis._1025 import (
        CylindricalGearTwoDimensionalFEAnalysis,
    )
    from mastapy._private.gears.gear_two_d_fe_analysis._1026 import (
        FindleyCriticalPlaneAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.gear_two_d_fe_analysis._1019": [
            "CylindricalGearMeshTIFFAnalysis"
        ],
        "_private.gears.gear_two_d_fe_analysis._1020": [
            "CylindricalGearMeshTIFFAnalysisDutyCycle"
        ],
        "_private.gears.gear_two_d_fe_analysis._1021": [
            "CylindricalGearSetTIFFAnalysis"
        ],
        "_private.gears.gear_two_d_fe_analysis._1022": [
            "CylindricalGearSetTIFFAnalysisDutyCycle"
        ],
        "_private.gears.gear_two_d_fe_analysis._1023": ["CylindricalGearTIFFAnalysis"],
        "_private.gears.gear_two_d_fe_analysis._1024": [
            "CylindricalGearTIFFAnalysisDutyCycle"
        ],
        "_private.gears.gear_two_d_fe_analysis._1025": [
            "CylindricalGearTwoDimensionalFEAnalysis"
        ],
        "_private.gears.gear_two_d_fe_analysis._1026": ["FindleyCriticalPlaneAnalysis"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "CylindricalGearMeshTIFFAnalysis",
    "CylindricalGearMeshTIFFAnalysisDutyCycle",
    "CylindricalGearSetTIFFAnalysis",
    "CylindricalGearSetTIFFAnalysisDutyCycle",
    "CylindricalGearTIFFAnalysis",
    "CylindricalGearTIFFAnalysisDutyCycle",
    "CylindricalGearTwoDimensionalFEAnalysis",
    "FindleyCriticalPlaneAnalysis",
)



"""WindTurbineCertificationReport"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.list_with_selected_item import (
    promote_to_list_with_selected_item,
)
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import list_with_selected_item
from mastapy._private.system_model.analyses_and_results.flexible_pin_analyses import (
    _6634,
)
from mastapy._private.system_model.analyses_and_results.load_case_groups import _6007
from mastapy._private.system_model.analyses_and_results.static_loads import _7728

_WIND_TURBINE_CERTIFICATION_REPORT = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.FlexiblePinAnalyses",
    "WindTurbineCertificationReport",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results.system_deflections import (
        _3095,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound import (
        _3244,
    )
    from mastapy._private.system_model.part_model import _2751

    Self = TypeVar("Self", bound="WindTurbineCertificationReport")
    CastSelf = TypeVar(
        "CastSelf",
        bound="WindTurbineCertificationReport._Cast_WindTurbineCertificationReport",
    )


__docformat__ = "restructuredtext en"
__all__ = ("WindTurbineCertificationReport",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_WindTurbineCertificationReport:
    """Special nested class for casting WindTurbineCertificationReport to subclasses."""

    __parent__: "WindTurbineCertificationReport"

    @property
    def combination_analysis(self: "CastSelf") -> "_6634.CombinationAnalysis":
        return self.__parent__._cast(_6634.CombinationAnalysis)

    @property
    def wind_turbine_certification_report(
        self: "CastSelf",
    ) -> "WindTurbineCertificationReport":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class WindTurbineCertificationReport(_6634.CombinationAnalysis):
    """WindTurbineCertificationReport

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _WIND_TURBINE_CERTIFICATION_REPORT

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def extreme_load_case(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_StaticLoadCase":
        """ListWithSelectedItem[mastapy.system_model.analyses_and_results.static_loads.StaticLoadCase]"""
        temp = pythonnet_property_get(self.wrapped, "ExtremeLoadCase")

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_StaticLoadCase",
        )(temp)

    @extreme_load_case.setter
    @exception_bridge
    @enforce_parameter_types
    def extreme_load_case(self: "Self", value: "_7728.StaticLoadCase") -> None:
        generic_type = (
            list_with_selected_item.ListWithSelectedItem_StaticLoadCase.implicit_type()
        )
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "ExtremeLoadCase", value)

    @property
    @exception_bridge
    def ldd(self: "Self") -> "list_with_selected_item.ListWithSelectedItem_DutyCycle":
        """ListWithSelectedItem[mastapy.system_model.analyses_and_results.load_case_groups.DutyCycle]"""
        temp = pythonnet_property_get(self.wrapped, "LDD")

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_DutyCycle",
        )(temp)

    @ldd.setter
    @exception_bridge
    @enforce_parameter_types
    def ldd(self: "Self", value: "_6007.DutyCycle") -> None:
        generic_type = (
            list_with_selected_item.ListWithSelectedItem_DutyCycle.implicit_type()
        )
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "LDD", value)

    @property
    @exception_bridge
    def nominal_load_case(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_StaticLoadCase":
        """ListWithSelectedItem[mastapy.system_model.analyses_and_results.static_loads.StaticLoadCase]"""
        temp = pythonnet_property_get(self.wrapped, "NominalLoadCase")

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_StaticLoadCase",
        )(temp)

    @nominal_load_case.setter
    @exception_bridge
    @enforce_parameter_types
    def nominal_load_case(self: "Self", value: "_7728.StaticLoadCase") -> None:
        generic_type = (
            list_with_selected_item.ListWithSelectedItem_StaticLoadCase.implicit_type()
        )
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "NominalLoadCase", value)

    @property
    @exception_bridge
    def design(self: "Self") -> "_2751.RootAssembly":
        """mastapy.system_model.part_model.RootAssembly

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Design")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def extreme_load_case_static_analysis(
        self: "Self",
    ) -> "_3095.RootAssemblySystemDeflection":
        """mastapy.system_model.analyses_and_results.system_deflections.RootAssemblySystemDeflection

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ExtremeLoadCaseStaticAnalysis")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def ldd_static_analysis(
        self: "Self",
    ) -> "_3244.RootAssemblyCompoundSystemDeflection":
        """mastapy.system_model.analyses_and_results.system_deflections.compound.RootAssemblyCompoundSystemDeflection

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LDDStaticAnalysis")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def nominal_load_case_static_analysis(
        self: "Self",
    ) -> "_3095.RootAssemblySystemDeflection":
        """mastapy.system_model.analyses_and_results.system_deflections.RootAssemblySystemDeflection

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "NominalLoadCaseStaticAnalysis")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_WindTurbineCertificationReport":
        """Cast to another type.

        Returns:
            _Cast_WindTurbineCertificationReport
        """
        return _Cast_WindTurbineCertificationReport(self)



"""LoadedSphericalRollerRadialBearingRow"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.bearings.bearing_results.rolling import _2274

_LOADED_SPHERICAL_ROLLER_RADIAL_BEARING_ROW = python_net_import(
    "SMT.MastaAPI.Bearings.BearingResults.Rolling",
    "LoadedSphericalRollerRadialBearingRow",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.bearings.bearing_results.rolling import _2278, _2284

    Self = TypeVar("Self", bound="LoadedSphericalRollerRadialBearingRow")
    CastSelf = TypeVar(
        "CastSelf",
        bound="LoadedSphericalRollerRadialBearingRow._Cast_LoadedSphericalRollerRadialBearingRow",
    )


__docformat__ = "restructuredtext en"
__all__ = ("LoadedSphericalRollerRadialBearingRow",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_LoadedSphericalRollerRadialBearingRow:
    """Special nested class for casting LoadedSphericalRollerRadialBearingRow to subclasses."""

    __parent__: "LoadedSphericalRollerRadialBearingRow"

    @property
    def loaded_roller_bearing_row(self: "CastSelf") -> "_2274.LoadedRollerBearingRow":
        return self.__parent__._cast(_2274.LoadedRollerBearingRow)

    @property
    def loaded_rolling_bearing_row(self: "CastSelf") -> "_2278.LoadedRollingBearingRow":
        from mastapy._private.bearings.bearing_results.rolling import _2278

        return self.__parent__._cast(_2278.LoadedRollingBearingRow)

    @property
    def loaded_spherical_roller_radial_bearing_row(
        self: "CastSelf",
    ) -> "LoadedSphericalRollerRadialBearingRow":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class LoadedSphericalRollerRadialBearingRow(_2274.LoadedRollerBearingRow):
    """LoadedSphericalRollerRadialBearingRow

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _LOADED_SPHERICAL_ROLLER_RADIAL_BEARING_ROW

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def loaded_bearing(
        self: "Self",
    ) -> "_2284.LoadedSphericalRollerRadialBearingResults":
        """mastapy.bearings.bearing_results.rolling.LoadedSphericalRollerRadialBearingResults

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LoadedBearing")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_LoadedSphericalRollerRadialBearingRow":
        """Cast to another type.

        Returns:
            _Cast_LoadedSphericalRollerRadialBearingRow
        """
        return _Cast_LoadedSphericalRollerRadialBearingRow(self)



"""NodeSelectionDepthOption"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_NODE_SELECTION_DEPTH_OPTION = python_net_import(
    "SMT.MastaAPI.SystemModel.FE", "NodeSelectionDepthOption"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="NodeSelectionDepthOption")
    CastSelf = TypeVar(
        "CastSelf", bound="NodeSelectionDepthOption._Cast_NodeSelectionDepthOption"
    )


__docformat__ = "restructuredtext en"
__all__ = ("NodeSelectionDepthOption",)


class NodeSelectionDepthOption(Enum):
    """NodeSelectionDepthOption

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _NODE_SELECTION_DEPTH_OPTION

    SURFACE_NODES = 0
    SOLID_NODES = 1


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


NodeSelectionDepthOption.__setattr__ = __enum_setattr
NodeSelectionDepthOption.__delattr__ = __enum_delattr



"""Context"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private import _0
from mastapy._private._internal import constructor, conversion, utility

_CONTEXT = python_net_import("SMT.MastaAPI.SystemModel.AnalysesAndResults", "Context")

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private._internal.typing import PathLike

    from mastapy._private.system_model import _2449
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
        _7450,
        _7452,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
        _7182,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7933,
        _7935,
        _7942,
        _7948,
        _7949,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
        _6953,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
        _6695,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses import (
        _6076,
        _6105,
        _6110,
        _6116,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.transfer_path_analyses import (
        _6193,
        _6194,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
        _6432,
        _6450,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses import _5804
    from mastapy._private.system_model.analyses_and_results.modal_analyses import (
        _4948,
        _4979,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
        _5528,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
        _5237,
        _5265,
    )
    from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
        _4707,
        _4708,
    )
    from mastapy._private.system_model.analyses_and_results.power_flows import _4438
    from mastapy._private.system_model.analyses_and_results.stability_analyses import (
        _4126,
        _4182,
    )
    from mastapy._private.system_model.analyses_and_results.static_loads import (
        _7727,
        _7728,
        _7734,
        _7899,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
        _3333,
        _3389,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed import (
        _3917,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
        _3654,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections import (
        _3120,
        _3127,
    )
    from mastapy._private.utility import _1810

    Self = TypeVar("Self", bound="Context")
    CastSelf = TypeVar("CastSelf", bound="Context._Cast_Context")


__docformat__ = "restructuredtext en"
__all__ = ("Context",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Context:
    """Special nested class for casting Context to subclasses."""

    __parent__: "Context"

    @property
    def system_deflection(self: "CastSelf") -> "_3120.SystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3120,
        )

        return self.__parent__._cast(_3120.SystemDeflection)

    @property
    def torsional_system_deflection(
        self: "CastSelf",
    ) -> "_3127.TorsionalSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _3127,
        )

        return self.__parent__._cast(_3127.TorsionalSystemDeflection)

    @property
    def dynamic_model_for_steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3333.DynamicModelForSteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3333,
        )

        return self.__parent__._cast(
            _3333.DynamicModelForSteadyStateSynchronousResponse
        )

    @property
    def steady_state_synchronous_response(
        self: "CastSelf",
    ) -> "_3389.SteadyStateSynchronousResponse":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses import (
            _3389,
        )

        return self.__parent__._cast(_3389.SteadyStateSynchronousResponse)

    @property
    def steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3654.SteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3654,
        )

        return self.__parent__._cast(_3654.SteadyStateSynchronousResponseOnAShaft)

    @property
    def steady_state_synchronous_response_at_a_speed(
        self: "CastSelf",
    ) -> "_3917.SteadyStateSynchronousResponseAtASpeed":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed import (
            _3917,
        )

        return self.__parent__._cast(_3917.SteadyStateSynchronousResponseAtASpeed)

    @property
    def dynamic_model_for_stability_analysis(
        self: "CastSelf",
    ) -> "_4126.DynamicModelForStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4126,
        )

        return self.__parent__._cast(_4126.DynamicModelForStabilityAnalysis)

    @property
    def stability_analysis(self: "CastSelf") -> "_4182.StabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4182,
        )

        return self.__parent__._cast(_4182.StabilityAnalysis)

    @property
    def power_flow(self: "CastSelf") -> "_4438.PowerFlow":
        from mastapy._private.system_model.analyses_and_results.power_flows import _4438

        return self.__parent__._cast(_4438.PowerFlow)

    @property
    def parametric_study_static_load(
        self: "CastSelf",
    ) -> "_4707.ParametricStudyStaticLoad":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4707,
        )

        return self.__parent__._cast(_4707.ParametricStudyStaticLoad)

    @property
    def parametric_study_tool(self: "CastSelf") -> "_4708.ParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4708,
        )

        return self.__parent__._cast(_4708.ParametricStudyTool)

    @property
    def dynamic_model_for_modal_analysis(
        self: "CastSelf",
    ) -> "_4948.DynamicModelForModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4948,
        )

        return self.__parent__._cast(_4948.DynamicModelForModalAnalysis)

    @property
    def modal_analysis(self: "CastSelf") -> "_4979.ModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4979,
        )

        return self.__parent__._cast(_4979.ModalAnalysis)

    @property
    def dynamic_model_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5237.DynamicModelAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5237,
        )

        return self.__parent__._cast(_5237.DynamicModelAtAStiffness)

    @property
    def modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5265.ModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5265,
        )

        return self.__parent__._cast(_5265.ModalAnalysisAtAStiffness)

    @property
    def modal_analysis_at_a_speed(self: "CastSelf") -> "_5528.ModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5528,
        )

        return self.__parent__._cast(_5528.ModalAnalysisAtASpeed)

    @property
    def multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5804.MultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5804,
        )

        return self.__parent__._cast(_5804.MultibodyDynamicsAnalysis)

    @property
    def dynamic_model_for_harmonic_analysis(
        self: "CastSelf",
    ) -> "_6076.DynamicModelForHarmonicAnalysis":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses import (
            _6076,
        )

        return self.__parent__._cast(_6076.DynamicModelForHarmonicAnalysis)

    @property
    def harmonic_analysis(self: "CastSelf") -> "_6105.HarmonicAnalysis":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses import (
            _6105,
        )

        return self.__parent__._cast(_6105.HarmonicAnalysis)

    @property
    def harmonic_analysis_for_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_6110.HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses import (
            _6110,
        )

        return self.__parent__._cast(
            _6110.HarmonicAnalysisForAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def harmonic_analysis_with_varying_stiffness_static_load_case(
        self: "CastSelf",
    ) -> "_6116.HarmonicAnalysisWithVaryingStiffnessStaticLoadCase":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses import (
            _6116,
        )

        return self.__parent__._cast(
            _6116.HarmonicAnalysisWithVaryingStiffnessStaticLoadCase
        )

    @property
    def dynamic_model_for_transfer_path_analysis(
        self: "CastSelf",
    ) -> "_6193.DynamicModelForTransferPathAnalysis":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses.transfer_path_analyses import (
            _6193,
        )

        return self.__parent__._cast(_6193.DynamicModelForTransferPathAnalysis)

    @property
    def modal_analysis_for_transfer_path_analysis(
        self: "CastSelf",
    ) -> "_6194.ModalAnalysisForTransferPathAnalysis":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses.transfer_path_analyses import (
            _6194,
        )

        return self.__parent__._cast(_6194.ModalAnalysisForTransferPathAnalysis)

    @property
    def harmonic_analysis_of_single_excitation(
        self: "CastSelf",
    ) -> "_6432.HarmonicAnalysisOfSingleExcitation":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6432,
        )

        return self.__parent__._cast(_6432.HarmonicAnalysisOfSingleExcitation)

    @property
    def modal_analysis_for_harmonic_analysis(
        self: "CastSelf",
    ) -> "_6450.ModalAnalysisForHarmonicAnalysis":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses_single_excitation import (
            _6450,
        )

        return self.__parent__._cast(_6450.ModalAnalysisForHarmonicAnalysis)

    @property
    def dynamic_analysis(self: "CastSelf") -> "_6695.DynamicAnalysis":
        from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
            _6695,
        )

        return self.__parent__._cast(_6695.DynamicAnalysis)

    @property
    def critical_speed_analysis(self: "CastSelf") -> "_6953.CriticalSpeedAnalysis":
        from mastapy._private.system_model.analyses_and_results.critical_speed_analyses import (
            _6953,
        )

        return self.__parent__._cast(_6953.CriticalSpeedAnalysis)

    @property
    def advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7182.AdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
            _7182,
        )

        return self.__parent__._cast(_7182.AdvancedTimeSteppingAnalysisForModulation)

    @property
    def advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7450.AdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7450,
        )

        return self.__parent__._cast(_7450.AdvancedSystemDeflection)

    @property
    def advanced_system_deflection_sub_analysis(
        self: "CastSelf",
    ) -> "_7452.AdvancedSystemDeflectionSubAnalysis":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7452,
        )

        return self.__parent__._cast(_7452.AdvancedSystemDeflectionSubAnalysis)

    @property
    def load_case(self: "CastSelf") -> "_7727.LoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7727,
        )

        return self.__parent__._cast(_7727.LoadCase)

    @property
    def static_load_case(self: "CastSelf") -> "_7728.StaticLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7728,
        )

        return self.__parent__._cast(_7728.StaticLoadCase)

    @property
    def advanced_time_stepping_analysis_for_modulation_static_load_case(
        self: "CastSelf",
    ) -> "_7734.AdvancedTimeSteppingAnalysisForModulationStaticLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7734,
        )

        return self.__parent__._cast(
            _7734.AdvancedTimeSteppingAnalysisForModulationStaticLoadCase
        )

    @property
    def time_series_load_case(self: "CastSelf") -> "_7899.TimeSeriesLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7899,
        )

        return self.__parent__._cast(_7899.TimeSeriesLoadCase)

    @property
    def analysis_case(self: "CastSelf") -> "_7933.AnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7933,
        )

        return self.__parent__._cast(_7933.AnalysisCase)

    @property
    def compound_analysis_case(self: "CastSelf") -> "_7935.CompoundAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7935,
        )

        return self.__parent__._cast(_7935.CompoundAnalysisCase)

    @property
    def fe_analysis(self: "CastSelf") -> "_7942.FEAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7942,
        )

        return self.__parent__._cast(_7942.FEAnalysis)

    @property
    def static_load_analysis_case(self: "CastSelf") -> "_7948.StaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7948,
        )

        return self.__parent__._cast(_7948.StaticLoadAnalysisCase)

    @property
    def time_series_load_analysis_case(
        self: "CastSelf",
    ) -> "_7949.TimeSeriesLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7949,
        )

        return self.__parent__._cast(_7949.TimeSeriesLoadAnalysisCase)

    @property
    def context(self: "CastSelf") -> "Context":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class Context(_0.APIBase):
    """Context

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONTEXT

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def comment(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get(self.wrapped, "Comment")

        if temp is None:
            return ""

        return temp

    @comment.setter
    @exception_bridge
    @enforce_parameter_types
    def comment(self: "Self", value: "str") -> None:
        pythonnet_property_set(
            self.wrapped, "Comment", str(value) if value is not None else ""
        )

    @property
    @exception_bridge
    def name(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get(self.wrapped, "Name")

        if temp is None:
            return ""

        return temp

    @name.setter
    @exception_bridge
    @enforce_parameter_types
    def name(self: "Self", value: "str") -> None:
        pythonnet_property_set(
            self.wrapped, "Name", str(value) if value is not None else ""
        )

    @property
    @exception_bridge
    def save_history_information(self: "Self") -> "_1810.FileHistoryItem":
        """mastapy.utility.FileHistoryItem

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SaveHistoryInformation")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def design_properties(self: "Self") -> "_2449.Design":
        """mastapy.system_model.Design

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DesignProperties")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ReportNames")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @exception_bridge
    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputDefaultReportTo", file_path)

    @exception_bridge
    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetDefaultReportWithEncodedImages"
        )
        return method_result

    @exception_bridge
    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputActiveReportTo", file_path)

    @exception_bridge
    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputActiveReportAsTextTo", file_path)

    @exception_bridge
    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetActiveReportWithEncodedImages"
        )
        return method_result

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportTo",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsMastaReport",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsTextTo",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = pythonnet_method_call(
            self.wrapped,
            "GetNamedReportWithEncodedImages",
            report_name if report_name else "",
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_Context":
        """Cast to another type.

        Returns:
            _Cast_Context
        """
        return _Cast_Context(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.bolts._1678 import AxialLoadType
    from mastapy._private.bolts._1679 import BoltedJointMaterial
    from mastapy._private.bolts._1680 import BoltedJointMaterialDatabase
    from mastapy._private.bolts._1681 import BoltGeometry
    from mastapy._private.bolts._1682 import BoltGeometryDatabase
    from mastapy._private.bolts._1683 import BoltMaterial
    from mastapy._private.bolts._1684 import BoltMaterialDatabase
    from mastapy._private.bolts._1685 import BoltSection
    from mastapy._private.bolts._1686 import BoltShankType
    from mastapy._private.bolts._1687 import BoltTypes
    from mastapy._private.bolts._1688 import ClampedSection
    from mastapy._private.bolts._1689 import ClampedSectionMaterialDatabase
    from mastapy._private.bolts._1690 import DetailedBoltDesign
    from mastapy._private.bolts._1691 import DetailedBoltedJointDesign
    from mastapy._private.bolts._1692 import HeadCapTypes
    from mastapy._private.bolts._1693 import JointGeometries
    from mastapy._private.bolts._1694 import JointTypes
    from mastapy._private.bolts._1695 import LoadedBolt
    from mastapy._private.bolts._1696 import RolledBeforeOrAfterHeatTreatment
    from mastapy._private.bolts._1697 import StandardSizes
    from mastapy._private.bolts._1698 import StrengthGrades
    from mastapy._private.bolts._1699 import ThreadTypes
    from mastapy._private.bolts._1700 import TighteningTechniques
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.bolts._1678": ["AxialLoadType"],
        "_private.bolts._1679": ["BoltedJointMaterial"],
        "_private.bolts._1680": ["BoltedJointMaterialDatabase"],
        "_private.bolts._1681": ["BoltGeometry"],
        "_private.bolts._1682": ["BoltGeometryDatabase"],
        "_private.bolts._1683": ["BoltMaterial"],
        "_private.bolts._1684": ["BoltMaterialDatabase"],
        "_private.bolts._1685": ["BoltSection"],
        "_private.bolts._1686": ["BoltShankType"],
        "_private.bolts._1687": ["BoltTypes"],
        "_private.bolts._1688": ["ClampedSection"],
        "_private.bolts._1689": ["ClampedSectionMaterialDatabase"],
        "_private.bolts._1690": ["DetailedBoltDesign"],
        "_private.bolts._1691": ["DetailedBoltedJointDesign"],
        "_private.bolts._1692": ["HeadCapTypes"],
        "_private.bolts._1693": ["JointGeometries"],
        "_private.bolts._1694": ["JointTypes"],
        "_private.bolts._1695": ["LoadedBolt"],
        "_private.bolts._1696": ["RolledBeforeOrAfterHeatTreatment"],
        "_private.bolts._1697": ["StandardSizes"],
        "_private.bolts._1698": ["StrengthGrades"],
        "_private.bolts._1699": ["ThreadTypes"],
        "_private.bolts._1700": ["TighteningTechniques"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AxialLoadType",
    "BoltedJointMaterial",
    "BoltedJointMaterialDatabase",
    "BoltGeometry",
    "BoltGeometryDatabase",
    "BoltMaterial",
    "BoltMaterialDatabase",
    "BoltSection",
    "BoltShankType",
    "BoltTypes",
    "ClampedSection",
    "ClampedSectionMaterialDatabase",
    "DetailedBoltDesign",
    "DetailedBoltedJointDesign",
    "HeadCapTypes",
    "JointGeometries",
    "JointTypes",
    "LoadedBolt",
    "RolledBeforeOrAfterHeatTreatment",
    "StandardSizes",
    "StrengthGrades",
    "ThreadTypes",
    "TighteningTechniques",
)
